#!/bin/ksh
#
# Script removes installed products
# Return codes:
#   0 = OK
#   1 = no products to delete
#   2 = failed
#   3 = failed due to running processes found
#

PROGNAME=$(basename $0)

Err_report() {
   case $1 in
      #$NLS-E$ warn) print -u2 "$PROGNAME warning: $2,continuing ..."
	  warn) print -u2 "`nls_replace 'KCI0200I' $PROGNAME \"$2\"`"
            sleep 2
            return
            ;;
      #$NLS-E$ fail) print -u2 "$PROGNAME failure: $2."
	  fail) print -u2 "$PROGNAME `nls_replace 'KCI0201I'`: $2."
            exit 2
            ;;
      info) print -u2 "$PROGNAME        : $2."
            return
            ;;
   esac
}

Use_report() {
    print -u2 "$PROGNAME [-f] [-i] [-h candle_directory] [product platformCode]"
    #$NLS-E$ "\t-f Force delete, suppressing confirmation messages and prompts."
	print -u2 "\t-f `nls_replace 'KCI0202I'`"
    #$NLS-E$ "\t-i Ignore all running processes."
	print -u2 "\t-i `nls_replace 'KCI0203I'`"
    #$NLS-E$ "\t'product' A two-letter code for the product to be uninstalled."
	print -u2 "\t'product' `nls_replace 'KCI0204I'`"
    #$NLS-E$ "\t'platformCode' Platform code (such as aix513, sol286, hp11, etc.) for the product."
	print -u2 "\t'platformCode' `nls_replace 'KCI0205I'`"
    exit 2
}

# Uninstall a product and its prereqs
#
# This function is called recursively and we have to be sure the variables are used locally,
# but for SLES10 the variables 'pc', 'platform' are not local and are rewritten when the function is called recursively.
# The function is executed in its own shell by placing parenthesis within the function brackets.
# The function gets its own copy of the environment when is called and any changes are not reflected in the calling script which is its own function.
uninstall_product() { (
  typeset pc=$1
  typeset platform=$2
  typeset skipComp=$3  # skip these components when checking for shared prereq
  typeset sharedPrereq="" 

  [[ "$skipComp" = "" ]] && skipComp=$pc$platform

  # Nuke CandleHome!
  if [[ "$pc" = "REMOVE" && "$platform" = "EVERYTHING" ]]
  then
    #$NLS-E$ "Removing ITM home: $CANDLEHOME\n"
	print "`nls_replace 'KCI0206I'`: $CANDLEHOME\n"
    cd $originalDir
    cmdHome=$(cd $(dirname $0) ; dirname $(pwd) )
    if [[ $(pwd) = "$CANDLEHOME/bin" || "$CANDLEHOME" = "$cmdHome" ]]
    then
      #$NLS-E$ "$CANDLEHOME/bin may have to be removed manually after this script completes"
	  Err_report warn "`nls_replace 'KCI0207I' $CANDLEHOME/bin `"
    fi
    #$NLS-E$ Err_report warn "Purging $CANDLEHOME"
	Err_report warn "`nls_replace 'KCI0208I' $CANDLEHOME`"


    if [ -f $CANDLEHOME/registry/AutoStart ]
    then
       remove_autostart
    fi

    hp_forcewait

    rm -rf $CANDLEHOME

    remove_links
    exit
  fi

  # Not installed if there's no VER file
  cd $regDir
  vFile=$pc$platform.ver
  #$NLS-E$ "product \"$pc\" for platform \"$platform\" not installed in $CANDLEHOME"
  if [ ! -f $vFile ] 
  then 
    Err_report warn "`nls_replace 'KCI0209I' "$pc" "$platform" "$CANDLEHOME"`"
    return
  fi

  # Remove Watchdog default configuration files and pas.dat
  if [ "$pc" = "ux" ] || [ "$pc" = "lz" ] 
  then
    rm -f $CANDLEHOME/config/CAP/k"$pc"_default.xml 2> /dev/null
    rm -f $CANDLEHOME/config/CAP/kca_default.xml 2> /dev/null
    rm -f $CANDLEHOME/config/CAP/pas.dat 2> /dev/null
    rm -f $CANDLEHOME/config/CAP/kwgcap.xsd 2> /dev/null
  else
    rm -f $CANDLEHOME/config/CAP/k"$pc"_default.xml 2> /dev/null
  fi

  # Delete prereqs. Get each prereq for the product (except ci and jr)
  for pre in $(grep "^preReq" $vFile | grep -v " ci" | grep -v " jr" | grep -v " none" |cut -f1 -d"|"|cut -f3 -d " ")
  do
    prePC=$(print $pre|cut -c1-2)
    preArch=${pre#$prePC}
    # check if this prereq component ared shared as prereq by other component
    sharedPrereq=""
    for comp in $(ls *.ver | grep -v "^ci" | grep -v "^jr")
    do
      comp=${comp%.ver}
      skip=$(print $skipComp | grep "$comp")
      if [ "$skip" != "" ]
      then
        # this component should be skipped,
        # because it is going to be removed
        continue
      fi
      tmpSharedPrereq=$(grep " = $pre" ${comp}.ver)
      [[ -n "$tmpSharedPrereq" ]] && sharedPrereq="$sharedPrereq $comp"
    done
    #sharedPrereq=$(grep " = $pre" $(ls *.ver|grep -v "$vFile"))
    # remove this prereq component recursively
    if [ -z "$sharedPrereq" ]
    then
      # add this prereq component to the skip list,
      # for it is going to be removed
      have=$(print $skipComp | grep  "^$prePC$preArch")
      [[ "$have" = "" ]] && skipComp="$skipComp $prePC$preArch"
      uninstall_product $prePC $preArch "$skipComp"
    fi
  done

  # Remove the product
  # OS agent is slow to down go, wait for it
  if [ "$pc" = "ux" ]
  then
    hp_forcewait
  fi
  #$NLS-E$ "removed from $CANDLEHOME" 
  remove_product $pc $platform "`nls_replace 'KCI0210I' $CANDLEHOME`" 
  update_autostart $pc

  # Synchronize/remove 'localconfig' directories for product(s) just removed.
  # Keep stderr printing to the screen to catch possible cricital errors
  $CANDLEHOME/bin/syncLocalConfDirs.sh >/dev/null
) }


update_autostart()
{
   if [ "$(whoami)" = "root" ]; then
    if [ -f $CANDLEHOME/registry/AutoStart ]; then
	editString1="start $pc"
	editString2="stop $pc"
	filenum=`cat $CANDLEHOME/registry/AutoStart`
	CurRegPath=$CANDLEHOME/registry
	ArchTbl=$CurRegPath/archdsc.tbl
	DynShl=$CANDLEHOME/bin/dynarch.shl
	. $DynShl $ArchTbl 2>/dev/null
  
	os=$(print $cArch|cut -c1-2)
	[ "$os" = li ] && rcFile="/etc/init.d/ITMAgents$filenum"
	[ "$os" = lx ] && rcFile="/etc/init.d/ITMAgents$filenum"
	[ "$os" = lp ] && rcFile="/etc/init.d/ITMAgents$filenum"
	[ "$os" = ls ] && rcFile="/etc/init.d/ITMAgents$filenum"
	[ "$os" = hp ] && rcFile="/sbin/init.d/ITMAgents$filenum"
	[ "$os" = so ] && rcFile="/etc/init.d/ITMAgents$filenum"
	[ "$os" = ai ] && rcFile=/etc/rc.itm$filenum

          # looping is not required to delete lines using sed instead of ed
	  if [[ -n "$(grep "$editString1" $rcFile 2>/dev/null)" ]]; then
	     editString="/$editString1/d"
	     update_rcFile
   	     if [[ $checkit != 0 ]]; then
		  #$NLS-E$ Delete of agent start all record failed.	
	      Err_report fail "`nls_replace 'KCI1168E'`"
	     else
		  #$NLS-E$ Delete of agent start all record successful.
	      Err_report info "`nls_replace 'KCI1169I'`"
	     fi
	  fi
	  
          # looping is not required to delete lines using sed instead of ed
	  if [[ -n "$(grep "$editString2" $rcFile 2>/dev/null)" ]]; then
	     editString="/$editString2/d"
	     update_rcFile
   	     if [[ $checkit != 0 ]]; then
		  #$NLS-E$ Delete of agent start all record failed.	
	      Err_report fail "`nls_replace 'KCI1168E'`"
	     else
		  #$NLS-E$ Delete of agent start all record successful.
	      Err_report info "`nls_replace 'KCI1169I'`"
	     fi
	  fi
  
      fi
   fi
}

update_rcFile()
{
SEDscript=$CANDLEHOME/tmp/SEDscript
print "$editString" > $SEDscript
checkit=0
cp -f $rcFile ${rcFile}.new
checkit=$?
if [[ $checkit = 0 ]]; then
  sed -f $SEDscript ${rcFile}.new > $rcFile
  checkit=$?
  if [[ $checkit != 0 ]]; then
    cp -f ${rcFile}.new $rcFile
  fi
fi
rm -f ${rcFile}.new
rm -f $SEDscript
}

# Remove a product or a prereq (component)
remove_product() {
  product=$1
  binarch=$2
  inform=$3

  rm -rf $CANDLEHOME/$binarch/$product 2> /dev/null
  #$NLS-E$ "unable to remove product directory for $product"
  [ $? -ne 0 ] && Err_report warn "`nls_replace 'KCI0211I' $product`"
  #if file doesn't exist don't output error message
  if [ -f $CANDLEHOME/registry/$product$binarch.ver ]
  then
    rm $CANDLEHOME/registry/$product$binarch.ver 2> /dev/null
    #$NLS-E$ "unable to remove version file for $product"
	[ $? -ne 0 ] && Err_report warn "`nls_replace 'KCI0212I' $product`"
  fi

  name=$(grep "^$product" $regDir/proddsc.tbl|head -1|cut -f2 -d"|")
  #defect 55109, append "|" with $binarch to avoid hp11 & hp116 return together.
  platformDesc=$(grep "^$binarch|" $regDir/archdsc.tbl|cut -f2 -d"|")
  if [ -n "$inform" ]
  then
    print "$inform ..."
    #$NLS-E$ "  \"$name\" for platform $platformDesc"
	nls_replace 'KCI0213I' "$name" "$platformDesc"
  fi

  # Log the deletion also
  logfile=$CANDLEHOME/logs/candle_installation.log
  print "uninstall.sh  : $(date)" >> $logfile
  print "  >$inform .." >> $logfile
  print "  >\"$name\" for platform $platformDesc" >> $logfile
  #defect 82233, prevent TEPS config files from furthern processing
  if [ "$product" = "cq" ]
  then
  	if [ -d $CANDLEHOME/config ]
  	then
  		mv -f $CANDLEHOME/config/${product}.ini $CANDLEHOME/config/${product}.ini.bak
  		mv -f $CANDLEHOME/config/${product}.config $CANDLEHOME/config/${product}.config.bak
  		mv -f $CANDLEHOME/config/.ConfigData/k${product}env  $CANDLEHOME/config/.ConfigData/k${product}env.bak
    fi
  fi
}

# Delete old token files, and warn if there is another install running in this <candlehome>.

procTokFiles()
{
  typeset -i maxAge=5  # Remove "remote" token files older than 5 days.
  typeset -i age=0 dot=0 doy=0
  typeset PID name
  
  ls ${baseTok}* | grep -v $thisTok > /dev/null 2>&1  # Other installs?
  [ $? -eq 0 ] || return
  
  doy=$(date +"%j")  # Day of the year (001 - 366)
  
  # Remove token files:
  # 1) created on this machine that are no longer connected to any process.
  # 2) created on other machines that are older than maxAge.
  
  for name in $(ls ${baseTok}* | grep -v $thisTok)
  do
    cat $name | grep "$thisMach" > /dev/null 2>&1 
    if [ $? -eq 0 ]  # The token file was created on this machine.
    then
      PID=${name##*_}
      ps -p $PID | grep $PID > /dev/null 2>&1
      [ $? -ne 0 ] && rm -f $name
    else  
      cat $name | grep "|" > /dev/null 2>&1  # Ensure the day of year field exists.
      [ $? -eq 0 ] || continue
      
      dot=$(cat $name | cut -d"|" -f2 | cut -d"|" -f1)  # Day the token file was created (001 - 366).

      if [ doy -ge dot ]
      then
        age=doy-dot
      else  # This could happen towards the end of a year, so "normalize" the day of the year.
        doy=366+doy
        age=doy-dot
      fi

      [ age -gt maxAge ] && rm -f $name
    fi
  done
  
  # Warn the user about possible simultaneous installs.
  
  ls ${baseTok}* | grep -v $thisTok > /dev/null 2>&1  # Check for other installs.
  if [ $? -eq 0 ] 
  then
  #$NLS-E$ "\nAn install may currently be running in \"$CANDLEHOME\" from"
  #$NLS-E$ "the following machine(s): \n"
	print " "
	nls_replace 'KCI0215I' \"$CANDLEHOME\"
	print " "

    for name in $(ls ${baseTok}* | grep -v $thisTok)
    do
      print "  \c"; cat $name
    done
  
    #$NLS-E$ "\nContinue with this uninstallation [ y or n; \"n\" is default ]?  \c"
	print "\n`nls_replace 'KCI0217I'` [ 1-`nls_replace 'KCI0197I'`, 2-`nls_replace 'KCI0198I'`; \"2\" `nls_replace 'KCI0199I'` ]? \c"
    read
    case $REPLY in
      y*|Y*|1) ;;
    
          *) rm -f $thisTok
             exit
             ;;
    esac
  fi
}
# Check for running processes before uninstall

checkProcesses()
{
  typeset pFile=$CANDLEHOME/registry/proddsc.tbl
  typeset rFile=$CANDLEHOME/config/.ConfigData/RunInfo
  typeset PID desc fieldSep fld23 msg pc proc 
  typeset thisMachShort 

  # No RunInfo means nothing's running
  [ ! -f $rFile ] && return
  
  # Determine whether it's BigK or dinkySQL.
  
  fieldSep=$(grep "FIELDSEP" $rFile | cut -d "=" -f2 2> /dev/null)
  
  # See if there are any agents/CMS's running from this <candlehome> on this machine.
  
  if [ -n "$fieldSep" ]  # BigK.
  then
    # EJF (#11545) make the check for the hostname in the RunInfo file a bit smarter
    
    # check if thisMach contains a fully qualifed hostname
    print $thisMach | grep "\." > /dev/null 2>&1
    
    # if thisMach does contain a fully qualified hostname
    if [[ $? -eq 0 ]]
    then
      # search for the fully qualified name in RunInfo
      cat $rFile | grep -i "^$thisMach$fieldSep" > /dev/null 2>&1
      
      # if the fully qualified name was found in RunInfo
      if [[ $? -eq 0 ]]
      then
        # record the match
        fld23=$(cat $rFile | grep -i "^$thisMach$fieldSep" | cut -d "$fieldSep" -f2,3)  # fld23 -> ms|35594
      
      # else search RunInfo for the short name
      else
        # make the short name and search RunInfo for it
        thisMachShort=$(print $thisMach | cut -d "." -f1)
        cat $rFile | grep -i "^$thisMachShort$fieldSep" > /dev/null 2>&1
        
        # if the short name was found in RunInfo
        if [[ $? -eq 0 ]]
        then
          # record the match
          fld23=$(cat $rFile | grep -i "^$thisMachShort$fieldSep" | cut -d "$fieldSep" -f2,3)  # fld23 -> ms|35594
          
        else
          # neither the full nor short name was found in RunInfo so return
          return
        fi
      fi
    
    # else thisMach contains a short hostname
    else
      # search RunInfo for the short name
      cat $rFile | grep -i "^$thisMach[$fieldSep\.]" > /dev/null 2>&1
      
      # if the short name was found in RunInfo
      if [[ $? -eq 0 ]]
      then
        # record the match
        fld23=$(cat $rFile | grep -i "^$thisMach[$fieldSep\.]" | cut -d "$fieldSep" -f2,3)  # fld23 -> ms|35594
          
      else
        # neither the full nor short name was found in RunInfo so return
        return
      fi
    fi
    
  else  # dinkySQL.
    cat $rFile | sed "s/  */ /g" | grep "$thisMach" | cut -c1 | grep "N" > /dev/null 2>&1
    [ $? -eq 0 ] || return
    fld23=$(cat $rFile | sed "s/  */ /g" | grep "$thisMach" | grep "^N" | cut -d" " -f2)  # fld23 -> ms35594
  fi
  
  # Check to see if the processes are actually running.
  
  for proc in $fld23
  do
    [ -n "$fieldSep" ] && PID=$(print "$proc" | cut -d "$fieldSep" -f2) || PID=$(print $proc | cut -c3-)
    ps -p $PID | grep $PID > /dev/null 2>&1
    [ $? -eq 0 ] || continue
    #$NLS-E$ "\\nThe following processes must be stopped before attempting uninstall: \\n"
	msg="\\n`nls_replace 'KCI0218I'` \\n"
    break
  done
  
  if [ -n "$msg" ]
  then
    print "$msg"
    for proc in $fld23
    do
      [ -n "$fieldSep" ] && pc=$(print "$proc" | cut -d "$fieldSep" -f1) || pc=$(print $proc | cut -c1-2)
    
      # Get the product description from the proddsc.tbl file.  If there are running processes,
      # then this file should exist.
    
      if [ -r $pFile ]  
      then
        desc=$(grep "^$pc|" $pFile | head -1 | cut -d"|" -f2)  # desc -> "NetView/AIX Alert Adapter"
        [ -n "$desc" ] || desc=$pc  # Just in case.
      fi
    
      [ -n "$fieldSep" ] && PID=$(print "$proc" | cut -d "$fieldSep" -f2) || PID=$(print $proc | cut -c3-)
      #$NLS-E$ Product
      print "  `nls_replace 'KCI1170I'` = $desc  PID = $PID"
    done
    print
    exit 3

  fi
}
hp_forcewait()
{

#  OS agent is not cleaning up its children so we have to wait on HP for 
#  them to die

    CurRegPath=$CANDLEHOME/registry
    ArchTbl=$CurRegPath/archdsc.tbl
    DynShl=$CANDLEHOME/bin/dynarch.shl


    . $DynShl $ArchTbl 2>/dev/null
    os=$(print $cArch|cut -c1-2)
 
    if [ "$os" = hp ]
    then
	   #$NLS-E$ Waiting for agent to shutdown	
       print "`nls_replace 'KCI1171I'`"
       sleep 70
       if [ -d "$CANDLEHOME/../" ]
       then
           cd $CANDLEHOME/../
       fi
    fi

    return

}
remove_autostart()
{

    CurRegPath=$CANDLEHOME/registry
    ArchTbl=$CurRegPath/archdsc.tbl
    DynShl=$CANDLEHOME/bin/dynarch.shl


    . $DynShl $ArchTbl 2>/dev/null

    os=$(print $cArch|cut -c1-2)
  typeset -i filenum=$(cat $CANDLEHOME/registry/AutoStart 2> /dev/null);  #IZ58055
                                                                          #IZ58055
  #-----------------------------------------------------------------------#IZ58055
  # Define the commands to undo autostart for our platform.               #IZ58055
  #-----------------------------------------------------------------------#IZ58055
  case "$os" in                                                           #IZ58055
    li|lx|lp|ls)                                                          #IZ58055
      cmd="chkconfig --del ITMAgents$filenum > /dev/null 2>&1"            #IZ58055
      cmd="$cmd;rm -f /etc/init.d/ITMAgents$filenum"                      #IZ58055
      cmd="$cmd;rm -f /etc/rc.d/rc[0-6].d/K10ITMAgents$filenum"           #IZ58055
      cmd="$cmd;rm -f /etc/rc.d/rc[0-6].d/S99ITMAgents$filenum"           #IZ58055
      cmd="$cmd;rm -f /etc/init.d/rc[0-6].d/K10ITMAgents$filenum"         #IZ58055
      cmd="$cmd;rm -f /etc/init.d/rc[0-6].d/S99ITMAgents$filenum"         #IZ58055
      ;;                                                                  #IZ58055
    hp)                                                                   #IZ58055
      cmd="rm -f /sbin/rc0.d/K100ITMAgents$filenum"                       #IZ58055
      cmd="$cmd;rm -f /sbin/rc1.d/K100ITMAgents$filenum"                  #IZ58055
      cmd="$cmd;rm -f /sbin/rc2.d/S500ITMAgents$filenum"                  #IZ58055
      cmd="$cmd;rm -f /sbin/init.d/ITMAgents$filenum"                     #IZ58055
      ;;                                                                  #IZ58055
    so)                                                                   #IZ58055
      cmd="rm -f /etc/rc0.d/K10ITMAgents$filenum"                         #IZ58055
      cmd="$cmd;rm -f /etc/rc1.d/K10ITMAgents$filenum"                    #IZ58055
      cmd="$cmd;rm -f /etc/rc2.d/S99ITMAgents$filenum"                    #IZ58055
      cmd="$cmd;rm -f /etc/init.d/ITMAgents$filenum"                      #IZ58055
      ;;                                                                  #IZ58055
    ai)                                                                   #IZ58055
      cmd="rmitab rcitm$filenum"                                          #IZ58055
      cmd="$cmd;rm -f /etc/rc.itm$filenum"                                #IZ58055
      ;;                                                                  #IZ58055
    *)                                           # should never happen... #IZ58055
      cmd="print -u2 'internal error: os=$os is not valid'"               #IZ58055
      ;;                                                                  #IZ58055
  esac                                           # (case(os))             #IZ58055
                                                                          #IZ58055
  #-----------------------------------------------------------------------#IZ58055
  # If we're already root, run the command and return. Otherwise, we try  #IZ58055
  # to run the command interactively and let the user control how we      #IZ58055
  # proceed.                                                              #IZ58055
  #-----------------------------------------------------------------------#IZ58055
  if [ "$(whoami)" = "root" ]; then                                       #IZ58055
    eval "$cmd"                                                           #IZ58055
    return                                                                #IZ58055
  else
     #$NLS-E$ print "\nroot user access is required to remove automatic restart files"
     print "\n `nls_replace 'KCI0219I'`"
     # If we're not root and we're in force mode, bail out
     if [ "$force" = "yes" ]
     then
        return
     fi

    loop=yes

    while [ $loop = "yes" ]
    do
       su root -c "$cmd"
       rc=$?
       if [ $rc -ne 0 ]  # su failed
       then
          #$NLS-E$ print "\nIgnore [ i ] or Try again [ y, n; \"n\" is default ]?  \c"
		  print "\n `nls_replace 'KCI0220I'` [2-`nls_replace 'KCI0197I'`, 3-`nls_replace 'KCI0198I'`; \\"3\\" `nls_replace 'KCI0199I'`]? \c"
          read 
          case $REPLY in
            y*|Y*|2) 
              continue
            ;;
            i*|I*|1) 
              loop=no
              return
            ;;
            *) 
              #$NLS-E$ "Failing, Commands to be executed were:"
			  nls_replace 'KCI0221E'
              print "$cmd"
              loop=no
            ;;
         esac
      fi
    return
    done
  fi

}

uninstall_process()
{

	  # This returns JAVA_HOME to us on the command line - set to variable and use
	  export JAVA_HOME=`$CANDLEHOME/bin/CandleGetJavaHome`
	  #TEST print "JAVA_HOME var: $JAVA_HOME"

	  TEMP_pc=$1
      TEMP_platform=$2

	  # If exists
      if [ -f $CANDLEHOME/bin/uninstall-process.sh ]
      then

		# and is executable
        if [ -x $CANDLEHOME/bin/uninstall-process.sh ]
        then

	    	print ""
			#$NLS-E$ "Processing pre-uninstall operations..."
			print "`nls_replace 'KCI0248I'`"
    
			#TEST print "$CANDLEHOME/bin/uninstall-process.sh \"$JAVA_HOME\" \"$CANDLEHOME\" \"$TEMP_pc\" \"preuninstall\" \"$TEMP_platform\" \"uninstall\""
			#$CANDLEHOME/bin/uninstall-process.sh "$JAVA_HOME" "$CANDLEHOME" "$TEMP_pc" "preuninstall" "$TEMP_platform" "uninstall" 2>$CANDLEHOME/logs/uninstall-process.err

			$CANDLEHOME/bin/uninstall-process.sh "$JAVA_HOME" "$CANDLEHOME" "$TEMP_pc" "preuninstall" "$TEMP_platform" "uninstall" "$force" 2>$CANDLEHOME/logs/uninstall-process.err			
			typeset result=$?
			if [ $result -eq 0 ]
			then
				#$NLS-E$ "Processing pre-uninstall complete."
				print "`nls_replace 'KCI0249I'`"
				print ""
			fi
			return $result
      
		else

			#TEST print "OK, the permissions are off, lets try and set execute"
			#TEST print "chmod a+x $CANDLEHOME/bin/uninstall-process.sh"
			chmod a+x $CANDLEHOME/bin/uninstall-process.sh 2>/dev/null

			# Now check again
			if [ -x $CANDLEHOME/bin/uninstall-process.sh ]
			then

				# We fixed the problem, good

				print ""
				#$NLS-E$ "Processing pre-uninstall operations..."
				print "`nls_replace 'KCI0248I'`"
    
				#TEST print "$CANDLEHOME/bin/uninstall-process.sh \"$JAVA_HOME\" \"$CANDLEHOME\" \"$TEMP_pc\" \"preuninstall\" \"$TEMP_platform\" \"uninstall\""
				#$CANDLEHOME/bin/uninstall-process.sh "$JAVA_HOME" "$CANDLEHOME" "$TEMP_pc" "preuninstall" "$TEMP_platform" "uninstall" 2>$CANDLEHOME/logs/uninstall-process.err

				$CANDLEHOME/bin/uninstall-process.sh "$JAVA_HOME" "$CANDLEHOME" "$TEMP_pc" "preuninstall" "$TEMP_platform" "uninstall" "$force" 2>$CANDLEHOME/logs/uninstall-process.err			
				typeset result=$?
				if [ $result -eq 0 ]
				then
					#$NLS-E$ "Processing pre-uninstall complete."
					print "`nls_replace 'KCI0249I'`"
					print ""
				fi
				return $result

			else
			
				# OK, we tried once, now we tell the user for more advanced steps
				unProcessFile = "$CANDLEHOME/bin/uninstall-process.sh"
				print ""
				#$NLS-E$ "The file [$CANDLEHOME/bin/uninstall-process.sh] exists, but is not executable by this user."
				print "`nls_replace 'KCI1260I' "$unProcessFile"`"
				#$NLS-E$ "Please change the permission of this file to be executable by this user."
				print "`nls_replace 'KCI1261I'`"
				print ""

				# This is a bold step to exit the entire unintsaller, but warranted since they need to try and fix this,
				# and it's easy enough to re-enter the tool. Plus, the user might not see the message

				exit 1
				
			fi

		fi

      else
		# The file does not exist, which will often happen - we silently skip this
		print ""
      fi

}

# remove /opt/IBM/ITM/tmaitm6/links if ITM is installed to a non-default location
# if there is only the directory links under /opt/IBM/ITM/tmaitm6, then we remove the whole /opt/IBM/ITM
# if there are other files/directories under /opt/IBM/ITM or /opt/IBM/ITM/tmaitm6, then we just remove /opt/IBM/ITM/tmaitm6/links
remove_links()
{
  typeset defaultCH="/opt/IBM/ITM"
  typeset link_target=""
  typeset tmp=""

  if [[ "$CANDLEHOME" != "$defaultCH" && -d $defaultCH ]]
  then
    # search for symblink files under /opt/IBM/ITM
    for linkF in $(find ${defaultCH}/tmaitm6/links -type l 2>/dev/null)
    do
      link_target=`ls -l $linkF`
      link_target=${link_target##*-\> }

      # link_target=/opt/IBM/ITMxyz/tmaitm6/... -> tmp=xyz/tmaitm6/...
      # link_target=/opt/IBM/xyz/tmaitm6/... -> tmp=/opt/IBM/xyz/tmaitm6/...
      tmp=${link_target##$CANDLEHOME}
      if [ "$tmp" = "$link_target" ]
      then
        # this link doesn't point to this ITM
        continue 
      fi

      # tmp=xyz/tmaitm6/... -> tmp=xyz
      tmp=${tmp%%/*}
      if [ "$tmp" != ""  ]
      then
        # this link doesn't point to this ITM
        continue
      fi

      # this symblink file links to this ITM, it should be removed
      rm -f $linkF 1>/dev/null 2>&1
    done
    
    # remove /opt/IBM/ITM if it's empty (if it doesn't contains any kind of file)
    typeset -i file_num=`find $defaultCH ! -type d 2>&1 | wc -l`
    if [ $file_num = 0 ]
    then
      rm -rf $defaultCH 1>/dev/null 2>&1
    fi
  fi
}

uninstall_callpoint()
{
	productCode=$1
	
	export saveLang=$LANG
	
	CurRegPath=$CANDLEHOME/registry
	ArchTbl=$CurRegPath/archdsc.tbl
	DynShl=$CANDLEHOME/bin/dynarch.shl

	. $DynShl $ArchTbl 2>/dev/null
	
	baseArch=${cArch%%[0-9]*}
	pcInstalled=$(ls $CANDLEHOME/registry/$productCode$baseArch*.ver 2>/dev/null)
	[ -z "$pcInstalled" ] && return
	
	useJreArch=$cArch
	
	# in case we are running platform lx we need to modify java arch prerequisite
	if [ "$baseArch" = "lx" ]; then
	  export LANG=C
	  cArchJava=$(grep "^preReqALL = jr" $pcInstalled 2>/dev/null | cut -d"=" -f2 | cut -d "|" -f1 | cut -c 4-)
	  export LANG=$saveLang
	  #use cArchJava only if component has jre prereq	
	  [ -n "$cArchJava" ] && useJreArch=$cArchJava
	fi

	setJavaEnv $useJreArch
	
	setBinLibArchs $cArch $productCode
	# echo "Product arch = $binArch"
	baseArch=${cArch%%[0-9]*}
	export LANG=C
	pcVRMF=$(grep "^VRMF =" $CANDLEHOME/registry/$productCode$baseArch*.ver 2>/dev/null | cut -d"=" -f2)
	export LANG=$saveLang
	plugin_type=install
	plugin_action=uninstall
	
	# if there is no VRMF in registry/<pc><arch>.ver file - create VRMF based on "vel" and "ver"
	# VRMF = 0+ver+rel+0
	if [ -z "$pcVRMF" ];
	then
	 export LANG=C
	 pcVER=$(grep "^ver =" $CANDLEHOME/registry/$productCode$baseArch*.ver 2>/dev/null | cut -d"=" -f2)
	 pcREL=$(grep "^rel =" $CANDLEHOME/registry/$productCode$baseArch*.ver 2>/dev/null | cut -d"=" -f2)
	 export LANG=$saveLang
		# Check if ver and rel can be read from ver file
		if [ -z "$pcVER" ] || [ -z "$pcREL" ]
		then
		  # Unable to determine product version
		  return
		fi
	 pcVRMF="0""$pcVER""$pcREL""0"
	fi
	
	$JREEXE -classpath $CLASSPATH $SAFE_MODE -DGlobalDbgLevel="DEBUG_MAX" -DInstallRASConfig="$CANDLEHOME/config/ITMConfigRAS.properties" ITMinstall.InstallComponentPluginCall $plugin_type $plugin_action $CANDLEHOME $cArch $productCode $binArch $pcVRMF
	rc=$?

	# echo "Return code is $rc"
}


###################################################################
#                         Main Routine                            #
###################################################################

bindir=`pwd`/$(dirname $0)
[ "$(print $0 | grep '\./')" = "" ] && [ "$(print $0 | grep '^/.*')" = "" ] && [ `pwd` = '/' ] && bindir=`pwd`$(dirname $0)
[ "$(print $0 | grep '^/.*')" != "" ] && bindir=$(dirname $0)

export TEXTDOMAINDIR=$bindir/../config/nls/msg
export PATH=$bindir:$PATH

export PATH=/usr/bin:/usr/sbin:/usr/ucb:$PATH
Mode=""
Menu="yes"
force="no"
ignore="no"
[ -z "$(whoami 2>/dev/null)" ] && alias whoami='id | cut -d"(" -f2 | cut -d")" -f1'

typeset -i ver=0 vr=0

typeset baseTok thisMach thisOS thisRec thisTok thisUser  # Variables used for the token file.

while getopts ":h:fi" OPTS
do case $OPTS in
   h) CANDLEHOME=$OPTARG
      ;;
   f) force="yes"
      ;;
   i) ignore="yes"
      ;;
   ?) Use_report
      ;;
   esac
done

shift $((OPTIND-1))

# Allow only product/platform combo or nothing
if [ $# -ge 2 ]
then
   pc="$1"; shift; platform="$1"
   Menu="no"
elif [ $# -eq 1 ]
then
   Use_report
else
   Menu="yes"
fi

[ -n "$CANDLEHOME" ] || CANDLEHOME=$(cd $(dirname $0) ; dirname $(pwd) )
#$NLS-E$ "specified ITM home is not a valid directory: $CANDLEHOME"
[ -d "$CANDLEHOME" ] || Err_report fail "`nls_replace 'KCI0222E'` $CANDLEHOME"
#$NLS-E$ "You have to be a root user or have the write access to directory $CANDLEHOME if you want to uninstall ITM."
[ -w "$CANDLEHOME" ] || Err_report fail "`nls_replace 'KCI1205E' $CANDLEHOME`"
export CANDLEHOME
originalDir=$(pwd)

if [ $(print "$CANDLEHOME" | wc -w) -ne 1 ]
then
  #$NLS-E$ "Blanks are not permitted in CANDLEHOME"
  Err_report fail "`nls_replace 'KCI0223E'`"
fi

export CANDLETMP=$CANDLEHOME/tmp

# LL - start token file stuff.

baseTok=$CANDLETMP/candle_install_

thisOS=$(uname -a | cut -d" " -f1)  # thisOS -> AIX
thisUser=$(whoami)

# Create the token file.

thisMach=$(uname -a | cut -d" " -f2)  # thisMach -> vulcan
thisTok=$baseTok${thisMach}_$$
touch $thisTok > /dev/null 2>&1
#$NLS-E$ "could not create token file"
[ $? -eq 0 ] || Err_report fail "`nls_replace 'KCI0224E'`"

# Build the description record, and add it to the token file.  This record will look like: 
# "AIX vulcan billy 17440 Friday Jun 08 14:21 2001 |159|".  The number between pipes (|)
# is the day of the year the file was created.

thisRec="$thisOS $thisMach $thisUser $$ $(date +"%A %B %d %H:%M %Y |%j|")"
print "$thisRec" > $thisTok

# Delete old token files, and warn if there is another install running in this <candlehome>.

procTokFiles 

# LL - end token file stuff.

if [ "$ignore" = "no" ]
then
  # Make sure nothing's running in this CandleHome
  checkProcesses
fi

# Get installer version and release number
ciVFile=cienv.ver
typeset curRel="" curVer="" regFile=""

regFile=$CANDLEHOME/registry/$ciVFile
#$NLS-E$ "could not read file: $regFile"
[ -r $regFile ] || Err_report fail "`nls_replace 'KCI0225E' $regFile`"

curVrmf=$(grep "^VRMF =" $regFile | cut -d"=" -f2)
if [ -z "$curVrmf" ]
then
    curVer=$(grep "^ver =" $regFile | cut -d"=" -f2)
    #$NLS-E$ "could not determine the version number from $regFile"
	[ -n "$curVer" ] || Err_report fail "`nls_replace 'KCI0226E' $regFile`"
    curRel=$(grep "^rel =" $regFile | cut -d"=" -f2)
    #$NLS-E$ "could not determine the release number from $regFile"
	[ -n "$curRel" ] || Err_report fail "`nls_replace 'KCI0227E' $regFile`"
else
    curVer1=$(print $curVrmf| cut -c 1,2)
    curVer2=$(print $curVrmf| cut -c 3,4)
    curVer3=$(print $curVrmf| cut -c 5,6)
    curVer4=$(print $curVrmf| cut -c 7,8)
fi

# Show banner
print " " 
print "*********** $(date) ******************"
if [[ "$(uname -s)" != "NONSTOP_KERNEL" ]]
then
  print "User      : $(whoami)\t Group: $(groups)"
  if [ -z "$curVrmf" ]
  then
    #$NLS-E$ "Host name : $(hostname)\t Installer Lvl:$curVer /$curRel" 
	print "`nls_replace 'KCI0228I'` : $(hostname)\t `nls_replace 'KCI0229I'` Lvl:$curVer /$curRel" 
  else
    #$NLS-E$ "Host name : $(hostname)\t Installer Lvl:$curVer1.$curVer2.$curVer3.$curVer4"
	print "`nls_replace 'KCI0228I'` : $(hostname)\t `nls_replace 'KCI0229I'` Lvl:$curVer1.$curVer2.$curVer3.$curVer4"
  fi
else
  #$NLS-E$ "User      : $(whoami)\t "
  print "`nls_replace 'KCI0230I'`      : $(whoami)\t "
  if [ -z "$curVrmf" ]
  then
    #$NLS-E$ "Installer Lvl:$curVer /$curRel" 
	print "`nls_replace 'KCI0229I'` Lvl:$curVer /$curRel" 
  else
    #$NLS-E$ " Installer Lvl:$curVer1.$curVer2.$curVer3.$curVer4"
	print "`nls_replace 'KCI0229I'`  Lvl:$curVer1.$curVer2.$curVer3.$curVer4"
  fi
fi		# end uname -s
print "ITM home  : $CANDLEHOME" 
print "***********************************************************" 

infoTmp=$CANDLEHOME/tmp/info.tmp_$$
infoTmp2=$CANDLEHOME/tmp/info.tmp2_$$
regDir=$CANDLEHOME/registry

# User entered a product code / platform combo in the args
if [ "$Menu" = "no" ]
then

  cd $regDir
  typeset sharedPrereq=""
  for comp in $(ls *.ver | grep -v "^ci")
  do
    comp=${comp%.ver}
    sharedPrereq=$(grep " = $pc$platform" ${comp}.ver)
    [[ -n "$sharedPrereq" ]] && break
  done
  if [ -n "$sharedPrereq" ]
  then
    #typeset prereqPC=$(print $comp | cut -c1-2)
    #typeset prereqName=$(grep "^$prereqPC" $regDir/proddsc.tbl|head -1|cut -f2 -d"|")
    #[[ -z "$prereqName" ]] && prereqName=$prereqPC

    Err_report fail "`nls_replace 'KCI1231E' \"$pc$platform\" \"$comp\"`"
  fi

  # Call the uninstall-process handler
  uninstall_process $pc $platform
  typeset result=$?

  uninstall_callpoint $pc
  
  if [ $result -eq 1 ]
  then
    #$NLS-E$ "Cancel Uninstall..."
    print "`nls_replace 'KCI1290I'`"
  elif [ $result -eq 0 ]
  then
	# check if product is installed based on product ver file and set isProdInstalled variable appropriately
	isProdInstalled="no"
	cd $regDir
	tmpVerFile=$pc$platform.ver
		if [ -f $tmpVerFile ]; then 
			isProdInstalled="yes"
		fi
	uninstall_product $pc $platform
		# if installed product was successfully uninstalled with all prerequisites and was executed by non-root, show additional message to the user
		if [ "$isProdInstalled" = "yes" ]; then 
			if [ "$(whoami)" != "root" ]; then
				#$NLS-E$ You have to be a root user to update auto restart script
				Err_report warn "`nls_replace 'KCI1167I'`"
			fi
		fi
  elif [ $result -eq 2 ]
  then
    # uninstall.sh failed.
	exit 2
  fi

  # cm12160 - for silent install, need to remove top level directory
  # if no more products are installed and the force flag (-f) is specified
  grepCmd=grep
  [ -f /usr/xpg4/bin/grep ] && grepCmd=/usr/xpg4/bin/grep
  remaining=$(find $regDir -name '*.ver' ! -exec $grepCmd -q 'preReqALL = none' {} \; -print 2>/dev/null)

  if [[ -z "$remaining" && "$force" = "yes" ]]; then
    #$NLS-E$ "Removing ITM home: $CANDLEHOME\n"
    print "`nls_replace 'KCI0231I'`: $CANDLEHOME\n"
  
    # remove the agent autostart files
    if [ -f $CANDLEHOME/registry/AutoStart ]
    then
      remove_autostart
    fi
    
    cd $originalDir
 
    hp_forcewait
 
    rm -rf $CANDLEHOME

    remove_links
  fi

# User entered nothing on command-line so we show the list of installed prods
else 
  rm -f $infoTmp2
  Response=""
  delPC=""
# listOfOs="aix hp sol l t"
# d42589 - refer the archdsc.tbl, filter app support: tps/tms/tpd/tpw
  listOfOs="aix hp sol li lx ls lp ta tv ts"
  while true
  do
    cd $regDir
    # Get a list of installed product version files. Show only version files that have prereqs
    grepCmd=grep
    [ -f /usr/xpg4/bin/grep ] && grepCmd=/usr/xpg4/bin/grep
    for OS in $listOfOs
    do
      for pc in $(find *${OS}*.ver -print 2>/dev/null)
      do
        pc=$(print $pc|cut -c 1-2)
        # GSKit should not be printed on the list of components available for uninstall and
        # should not be uninstalled until everything is removed, 
        # it must get removed along with CANDLEHOME directory
        # T1 should not be listed as an option on the menu since it is not a true component, 
        # but now integrated into the TEMS package.
        # JR should not be listed as an option on the uninstall menu since it is not a true ITM component.
         if [ "$pc" != "gs" ] && [ "$pc" != "t1" ] && [ "$pc" != "jr" ]
        then
          print $pc >> $infoTmp2
        fi
      done
    done
    
    if [ -z "$Response" ] && [ -f $infoTmp2 ]
    then
      #$NLS-E$ "\n...Products available to uninstall\n"
	  print "\n...`nls_replace 'KCI0232I'`\n"
      #$NLS-E$ "Num\tProduct [ Code  Platform Version:Release Description ]"
	  print "`nls_replace 'KCI0233I'`"
    fi

    # Get a list of installed product version files. Show only version files that have prereqs
    #grepCmd=grep
    #[ -f /usr/xpg4/bin/grep ] && grepCmd=/usr/xpg4/bin/grep
    #for pc in $(find *.ver ! -exec $grepCmd -q 'preReqALL = none' {} \; -print)
    #do
    #  pc=$(print $pc|cut -c 1-2)
    #  print $pc >> $infoTmp2
    #done

    # No products to list ... ask about removing CANDLEHOME
    if [ ! -f $infoTmp2 ]
    then
      print
      #$NLS-E$ "No products found to uninstall. Preparing to remove ITM home ..."
      nls_replace 'KCI0234I'
	  if [ "$force" = "no" ]
      then
        #$NLS-E$ "Confirm: CANDLEHOME=$CANDLEHOME  ... OK to delete? [y or n; \"n\" is default]: "
		print -n "`nls_replace 'KCI0235I'`: CANDLEHOME=$CANDLEHOME  ... `nls_replace 'KCI0236I'` [ 1-`nls_replace 'KCI0197I'`, 2-`nls_replace 'KCI0198I'`; \"2\" `nls_replace 'KCI0199I'` ]: "
          read answer
        else
          answer="y"
      fi
      case "$answer" in
        #$NLS-E$ y|Y|yes|YES) print "Removing ITM home: $CANDLEHOME\n"
		y|Y|yes|YES|1) print "`nls_replace 'KCI0237I'`: $CANDLEHOME\n"
	cd $originalDir
        cmdHome=$(cd $(dirname $0) ; dirname $(pwd) )
	if [[ $(pwd) = "$CANDLEHOME/bin" || "$CANDLEHOME" = "$cmdHome" ]]
	then
	  #$NLS-E$ "$CANDLEHOME/bin may have to be removed manually after this script completes"
	  Err_report warn "$CANDLEHOME/bin `nls_replace 'KCI0238I'`"
	fi
        #$NLS-E$ "Purging $CANDLEHOME"
		Err_report warn "`nls_replace 'KCI0239I'` $CANDLEHOME"
        if [ -f $CANDLEHOME/registry/AutoStart ]
        then
           remove_autostart
        fi
 
        hp_forcewait
 
        rm -rf $CANDLEHOME

        remove_links
        ;;
      esac
      exit 1
    fi

    sort -u -o $infoTmp $infoTmp2
    typeset -i index=0
    while read pc
    do
      name=$(grep "^$pc" $regDir/proddsc.tbl| head -1 |cut -f2 -d"|")
      for OS in $listOfOs
      do
        if [ -n "$(ls ${pc}$OS*.ver 2>/dev/null)" ]
        then
          for vFile in $(ls ${pc}$OS*.ver)
          do
            comp=${vFile%.ver}
            grepCmd=grep
            [ -f /usr/xpg4/bin/grep ] && grepCmd=/usr/xpg4/bin/grep
            preqComp=$(find *.ver -exec $grepCmd -q "preReqALL = $comp" {} \; -print)
            if [ "$preqComp" != "" ]
            then
              # this component is a prereq of other component,
              # it shouldn't be selected to uninstall
              # just skip it
              continue
            fi

	    index=$index+1
	    if [ "$Response" = "" ]
	    then
              platform=${vFile#$pc}
              platform=${platform%.ver}
	      vrmf=$(grep "^VRMF =" $vFile|cut -f3 -d" ")
	      if [ -z "$vrmf" ]
	      then
              	version=$(grep "^ver =" $vFile|cut -f3 -d" ")
              	release=$(grep "^rel =" $vFile|cut -f3 -d" ")
              	print "$index\t$pc  $platform\t v$version:r$release  $name"
	      else
		vrmf1=$(print $vrmf| cut -c 1,2)
		vrmf2=$(print $vrmf| cut -c 3,4)
		vrmf3=$(print $vrmf| cut -c 5,6)
		vrmf4=$(print $vrmf| cut -c 7,8)
		print "$index\t$pc  $platform\t v$vrmf1.$vrmf2.$vrmf3.$vrmf4 $name"
	      fi
	    elif [ "$Response" = $index ]
	    then
              platform=${vFile#$pc}
              platform=${platform%.ver}
	      vrmf=$(grep "^VRMF =" $vFile|cut -f3 -d" ")
	      if [ -z "$vrmf" ]
	      then
              	version=$(grep "^ver =" $vFile|cut -f3 -d" ")
              	release=$(grep "^rel =" $vFile|cut -f3 -d" ")
	      	delVersion=$version
	      	delRelease=$release
	      else
		vrmf1=$(print $vrmf| cut -c 1,2)
		vrmf2=$(print $vrmf| cut -c 3,4)
		vrmf3=$(print $vrmf| cut -c 5,6)
		vrmf4=$(print $vrmf| cut -c 7,8)
		delVersion=$vrmf1.$vrmf2.$vrmf3.$vrmf4
		delRelease=""
	      fi
	      delPC=$pc
	      delPlatform=$platform
	      delName=$name
	      break
	    fi
          done
        fi
      done
    done < $infoTmp
    rm -f $infoTmp $infoTmp2

    # List displayed and user responded ... now process response

    # User entered something
    if [ "$Response" != "" ]
    then
      # User picked a valid product to uninstall
      if [ "$delPC" != "" ]
      then
	if [ "$force" = "no" ]
	then
	  if [ -n "$delRelease" ]
	  then
            #$NLS-E$ "Confirm: $delPC  $delPlatform  v$delVersion:r$delRelease $delName ... OK to delete? [ y or n; \"n\" is default ]: "
			print -n "`nls_replace 'KCI0240I'`: $delPC  $delPlatform  v$delVersion:r$delRelease $delName ... `nls_replace 'KCI0241I'` [ 1-`nls_replace 'KCI0197I'`, 2-`nls_replace 'KCI0198I'`; \"2\" `nls_replace 'KCI0199I'` ]: "
	  else
            #$NLS-E$ print -n "Confirm: $delPC  $delPlatform  v$delVersion $delName ... OK to delete? [ y or n; \"n\" is default ]: "
			print -n "`nls_replace 'KCI0240I'`: $delPC  $delPlatform  v$delVersion $delName ... `nls_replace 'KCI0241I'` [ 1-`nls_replace 'KCI0197I'`, 2-`nls_replace 'KCI0198I'`; \"2\" `nls_replace 'KCI0199I'` ]: "
	  fi
          read answer
	else
	  answer="y"
	fi
        case "$answer" in
	  #$NLS-E$  y|Y|yes|YES|1) print "Uninstall product $delPC $delPlatform"
	  y|Y|yes|YES|1) print "`nls_replace 'KCI0247I' "$delPC" "$delPlatform"`"
	  
	  # Call the uninstall-process handler
	  uninstall_process $delPC $delPlatform
	typeset result=$?
	
	uninstall_callpoint $delPC
	
	if [ $result -eq 1 ]
	then
		#$NLS-E$ "Cancel Uninstall..."
        	print "`nls_replace 'KCI1290I'`"
	elif [ $result -eq 0 ]
	then
		# check if product is installed based on product ver file and set isProdInstalled variable appropriately
		isProdInstalled="no"
		cd $regDir
		tmpVerFile=$delPC$delPlatform.ver
			if [ -f $tmpVerFile ]; then 
				isProdInstalled="yes"
			fi
		uninstall_product $delPC $delPlatform
			# if installed product was successfully uninstalled with all prerequisites and was executed by non-root, show additional message to the user
			if [ "$isProdInstalled" = "yes" ]; then 
				if [ "$(whoami)" != "root" ]; then
					#$NLS-E$ You have to be a root user to update auto restart script
					Err_report warn "`nls_replace 'KCI1167I'`"
				fi
			fi
	elif [ $result -eq 2 ]
	then
		# uninstall.sh failed.
		exit 2
	fi
	  delPC=""
             ;;
        esac
      else
	#$NLS-E$ "$Response was not a valid selection, please try again"
	nls_replace 'KCI0242I' $Response
      fi
      Response=""

    # User entered nothing, or first time thru .. just prompt for a selection (or exit)
    else
      #$NLS-E$ "\nEnter number for a product to uninstall or \"EXIT\" to exit: "
	  print -n "\n`nls_replace 'KCI0243I' \\"99\\"` "
      read Response
      case "$Response" in
        x|X|exit|EXIT|99) exit
           ;;
      esac
    fi
  done
fi

exit
